<template>
  <basic-container>
    <avue-crud
      :addBtn="false"
      :option="option"
      :table-loading="loading"
      :data="data"
      ref="crud"
      v-model:search="search"
      v-model:page="mypage"
      @search-change="searchChange"
      @search-reset="searchReset"
      @current-change="currentChange"
      @size-change="sizeChange"
      @refresh-change="refreshChange"
      @on-load="onLoad"
    >
      <template #menu-left>
        <el-button type="primary" size="default" icon="el-icon-circle-plus" plain @click="handleExport">导出</el-button>
      </template>
      <template #menu="scope">
        <el-button type="primary" text size="default" icon="el-icon-document-delete" @click.stop="rejectBtn(scope.row, scope.index)">拒绝</el-button>
        <el-button type="primary" text size="default" icon="el-icon-document-add" @click.stop="acceptBtn(scope.row, scope.index)">接收</el-button>
      </template>
    </avue-crud>
  </basic-container>
</template>

<script>
import { exportBlob } from '@/api/common';
import { downloadXls } from '@/utils/util';
import { getToken } from '@/utils/auth';
import NProgress from 'nprogress';
import 'nprogress/nprogress.css';
export default {
  data() {
    return {
      search: {
        keyword: "",
        machineGroupCode: ""
      },
      loading: true,
      mypage: {
        size: 10,
        current: 1,
        total: 0,
      },
      option: {
        index: true,
        addBtn: false,
        editBtn: false,
        delBtn: false,
        labelWidth: 120,
        emptyBtn: false,
        searchLabelWidth: "120",
        searchSpan: 8,
        column: [
          {
            label: '任务编码',
            prop: 'programName',
            hide: true
          },
          {
            label: '文件编号',
            prop: ''
          },
          {
            label: '机床号',
            prop: 'machineCode',
          },
          {
            label: '文件名称',
            prop: 'name',
          },
          {
            label: '文件固化状态',
            prop: 'isCured',
          },
          {
            label: '文件到达时间',
            prop: 'arrivedTime',
          },
          {
            label: '文件数据库编号',
            prop: '',
          },
          {
            label: '关键信息',
            prop: 'keyword',
            search: true,
            hide: true,
          },
          {
            label: '机床规格型号',
            prop: 'machineSpec',
            search: true,
            hide: true,
            type: 'select',
            dicUrl: '/blade-system/dict-biz/dictionary?code=machine_spec',
            props: {
              label: 'dictValue',
              value: 'dictKey',
            },
            span: "8"
          }
        ],
      },
      data: [],
    };
  },
  methods: {
    acceptBtn(row) {
      this.$confirm('确定要接收吗?', {
        confirmButtonText: '是',
        cancelButtonText: '否',
        type: 'warning',
      }).then(() => {
        //调用接口
        this.loading = true;
        axios({
          url: '/blade-mdm/machineback/file/accept',
          method: 'post',
          data: {ids: row.id},
        }).then(
          res => {
            this.loading = false;
            this.onLoad();
          }
        );
      })
    },
    rejectBtn(row) {
      this.$confirm('确定要拒绝吗?', {
        confirmButtonText: '是',
        cancelButtonText: '否',
        type: 'warning',
      }).then(() => {
        //调用接口
        this.loading = true;
        axios({
          url: '/blade-mdm/machineback/file/reject',
          method: 'post',
          params: {ids: row.id},
        }).then(
          res => {
            this.loading = false;
            this.onLoad();
          }
        );
      })
    },
    handleExport(row,index) {  //导出
      this.$confirm('是否导出机床回传文件数据?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      }).then(() => {
        NProgress.start();
        exportBlob(
          `/blade-mdm/machineback/file/export-excel?${this.website.tokenHeader}=${getToken()}`
        ).then(res => {
          downloadXls(res.data, `机床回传文件数据${this.$dayjs().format('YYYY-MM-DD HH:mm:ss')}.xlsx`);
          NProgress.done();
        });
      });
    },
    searchReset() {
      //this.onLoad(this.mypage);
    },
    searchChange(params, done) {
      this.mypage.current = 1;
      this.onLoad();
      done();
    },
    currentChange(current) {
      this.mypage.current = current;
    },
    sizeChange(size) {
      this.mypage.size = size;
    },
    refreshChange() {
      
    },
    onLoad() {
      this.loading = true;
      var obj = {
        keyword: this.search.keyword,
        machineSpec: this.search.machineSpec,
        current: this.mypage.current,
        size: this.mypage.size,
      }
      axios({
        url: '/blade-mdm/machineback/file/page',
        method: 'get',
        params: obj,
      }).then(
        res => {
          const data = res.data.data;
          this.mypage.total = data.total;
          this.data = data.records;
          this.loading = false;
        },
        error => {
            
        }
      );

    }
  },
};
</script>

<style lang="scss">

</style>